searchNodes=[{"doc":"Elixir wrapper for the Argon2 password hashing function. Most applications will just need to use the add_hash/2 and check_pass/3 convenience functions in this module. For a lower-level API, see Argon2.Base . Configuration See the documentation for Argon2.Stats for information about configuration. Argon2 Argon2 is the winner of the Password Hashing Competition (PHC) . Argon2 is a memory-hard password hashing function which can be used to hash passwords for credential storage, key derivation, or other applications. Argon2 has the following three variants (Argon2id is the default): Argon2d - suitable for applications with no threats from side-channel timing attacks (eg. cryptocurrencies) Argon2i - suitable for password hashing and password-based key derivation Argon2id - a hybrid of Argon2d and Argon2i Argon2i, Argon2d, and Argon2id are parametrized by: A time cost, which defines the amount of computation realized and therefore the execution time, given in number of iterations A memory cost, which defines the memory usage, given in kibibytes A parallelism degree, which defines the number of parallel threads More information can be found in the documentation for the Argon2.Stats module and at the Argon2 reference C implementation repository . Comparison with Bcrypt / Pbkdf2 Argon2 has better password cracking resistance than Bcrypt and Pbkdf2. Its main advantage is that, as it is a memory-hard function, it is designed to withstand parallel attacks that use GPUs or other dedicated hardware.","ref":"Argon2.html","title":"Argon2","type":"module"},{"doc":"Hashes a password, using hash_pwd_salt/2 , and returns the password hash in a map. This is a convenience function that is especially useful when used with Ecto changesets. Options In addition to the :hash_key option show below, this function also takes options that are then passed on to the hash_pwd_salt/2 function in this module. See the documentation for hash_pwd_salt/2 for further details. :hash_key - the password hash identifier the default is :password_hash Example with Ecto The put_pass_hash function below is an example of how you can use add_hash to add the password hash to the Ecto changeset. defp put_pass_hash ( % Ecto.Changeset { valid? : true , changes : %{ password : password } } = changeset ) do change ( changeset , add_hash ( password ) ) end defp put_pass_hash ( changeset ) , do : changeset This function will return a changeset with %{password_hash: password_hash} added to the changes map.","ref":"Argon2.html#add_hash/2","title":"Argon2.add_hash/2","type":"function"},{"doc":"Checks the password, using verify_pass/2 , by comparing the hash with the password hash found in a user struct, or map. This is a convenience function that takes a user struct, or map, as input and seemlessly handles the cases where no user is found. Options :hash_key - the password hash identifier this does not need to be set if the key is :password_hash or :encrypted_password :hide_user - run the no_user_verify/1 function if no user is found the default is true Example The following is an example of using this function to verify a user's password: def verify_user ( %{ &quot;password&quot; =&gt; password } = params ) do params |&gt; Accounts . get_by ( ) |&gt; check_pass ( password ) end The Accounts.get_by function in this example takes the user parameters (for example, email and password) as input and returns a user struct or nil.","ref":"Argon2.html#check_pass/3","title":"Argon2.check_pass/3","type":"function"},{"doc":"Generate a random salt. The default length for the salt is 16 bytes. We do not recommend using a salt shorter than the default.","ref":"Argon2.html#gen_salt/1","title":"Argon2.gen_salt/1","type":"function"},{"doc":"Hashes a password with a randomly generated salt. Options In addition to the :salt_len option shown below, this function also takes options that are then passed on to the hash_password function in the Argon2.Base module. See the documentation for Argon2.Base.hash_password/3 for further details. :salt_len - the length of the random salt the default is 16 (the minimum is 8) bytes Examples The following examples show how to hash a password with a randomly-generated salt and then verify a password: iex&gt; hash = Argon2 . hash_pwd_salt ( &quot;password&quot; ) ...&gt; Argon2 . verify_pass ( &quot;password&quot; , hash ) true iex&gt; hash = Argon2 . hash_pwd_salt ( &quot;password&quot; ) ...&gt; Argon2 . verify_pass ( &quot;incorrect&quot; , hash ) false","ref":"Argon2.html#hash_pwd_salt/2","title":"Argon2.hash_pwd_salt/2","type":"function"},{"doc":"Runs the password hash function, but always returns false. This function is intended to make it more difficult for any potential attacker to find valid usernames by using timing attacks. This function is only useful if it is used as part of a policy of hiding usernames. Options This function should be called with the same options as those used by hash_pwd_salt/2 . Hiding usernames In addition to keeping passwords secret, hiding the precise username can help make online attacks more difficult. An attacker would then have to guess a username / password combination, rather than just a password, to gain access. This does not mean that the username should be kept completely secret. Adding a short numerical suffix to a user's name, for example, would be sufficient to increase the attacker's work considerably. If you are implementing a policy of hiding usernames, it is important to make sure that the username is not revealed by any other part of your application.","ref":"Argon2.html#no_user_verify/1","title":"Argon2.no_user_verify/1","type":"function"},{"doc":"Verifies a password by hashing the password and comparing the hashed value with a stored hash. See the documentation for hash_pwd_salt/2 for examples of using this function.","ref":"Argon2.html#verify_pass/2","title":"Argon2.verify_pass/2","type":"function"},{"doc":"Lower-level api for Argon2. These functions can be useful if you want more control over some of the options. In most cases, you will not need to call these functions directly.","ref":"Argon2.Base.html","title":"Argon2.Base","type":"module"},{"doc":"Calculate the length of the encoded hash.","ref":"Argon2.Base.html#encodedlen_nif/6","title":"Argon2.Base.encodedlen_nif/6","type":"function"},{"doc":"Translate the error code to an error message.","ref":"Argon2.Base.html#error_nif/1","title":"Argon2.Base.error_nif/1","type":"function"},{"doc":"","ref":"Argon2.Base.html#handle_error/1","title":"Argon2.Base.handle_error/1","type":"function"},{"doc":"Hash a password using Argon2.","ref":"Argon2.Base.html#hash_nif/10","title":"Argon2.Base.hash_nif/10","type":"function"},{"doc":"Hash a password using Argon2. Options There are six options: :t_cost - time cost :m_cost - memory usage :parallelism - number of parallel threads :format - output format this value can be :encoded - encoded with Argon2 crypt format :raw_hash - raw hash output in hexadecimal format :report - raw hash and encoded hash, together with the options used :encoded is the default :hashlen - length of the hash (in bytes) the default is 32 :argon2_type - Argon2 type this value should be 0 (Argon2d), 1 (Argon2i) or 2 (Argon2id) the default is 2 (Argon2id) The t_cost , m_cost , parallelism and argon2_type can also be set in the config. See the documentation for Argon2.Stats for more information about choosing these values. Examples The following example changes the default t_cost and m_cost : Argon2.Base . hash_password ( &quot;password&quot; , &quot;somesaltSOMESALT&quot; , [ t_cost : 4 , m_cost : 18 ] ) In the example below, the Argon2 type is changed to Argon2d: Argon2.Base . hash_password ( &quot;password&quot; , &quot;somesaltSOMESALT&quot; , [ argon2_type : 0 ] ) To use Argon2i, use argon2_type: 1 .","ref":"Argon2.Base.html#hash_password/3","title":"Argon2.Base.hash_password/3","type":"function"},{"doc":"","ref":"Argon2.Base.html#init/0","title":"Argon2.Base.init/0","type":"function"},{"doc":"Verify a password using Argon2.","ref":"Argon2.Base.html#verify_nif/3","title":"Argon2.Base.verify_nif/3","type":"function"},{"doc":"Module to provide statistics for the Argon2 password hashing function. The report/1 function in this module can be used to help you configure Argon2. Configuration The following four parameters can be set in the config file (these can all be overridden using keyword options): t_cost - time cost the amount of computation, given in number of iterations 8 is the default m_cost - memory usage 17 is the default - this will produce a memory usage of 128 MiB (2 ^ 17 KiB) parallelism - number of parallel threads 4 is the default argon2_type - argon2 variant to use 0 (Argon2d), 1 (Argon2i) or 2 (Argon2id) 2 is the default (Argon2id) It is important to note that the default values are not necessarily the recommended values. A lot will depend on what hardware you are using and how much time you want the hashing function to take. See the Choosing parameters section for more details. Test values The following values can be used to speed up tests. config :argon2_elixir , t_cost : 1 , m_cost : 8 NB. do not use these values in production. Choosing parameters The following is a guide on how to choose the parameters. Decide which type to use. If you do not know the difference between the types, choose Argon2id. Decide how many threads to use - the parallelism option. Decide how much memory each call should use - m_cost. Decide how much time each call should take. a. The Argon2 draft guidelines recommend 500 milliseconds (0.5 seconds). Run the function using the values chosen in steps 1-3. Work out the maximum t_cost (number of iterations) such that the running time does not exceed the value chosen in step 4. If the time taken exceeds the value chosen in step 4 even for one iteration, reduce the m_cost accordingly.","ref":"Argon2.Stats.html","title":"Argon2.Stats","type":"module"},{"doc":"Hash a password with Argon2 and print out a report. This function hashes the password and salt with Argon2.Base.hash_password/3 and prints out statistics which can help you choose how to configure Argon2. Options In addition to the options for Argon2.Base.hash_password/3 , there are also the following options: :password - the password used the default is &quot;password&quot; :salt - the salt used the default is &quot;somesaltSOMESALT&quot;","ref":"Argon2.Stats.html#report/1","title":"Argon2.Stats.report/1","type":"function"},{"doc":"All notable changes to this project will be documented in this file. The format is based on Keep a Changelog , and this project adheres to Semantic Versioning .","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Changes updated documentation and README","ref":"changelog.html#v2-4-1-2021-01-19","title":"Changelog - v2.4.1 (2021-01-19)","type":"extras"},{"doc":"Enhancements updated Makefile to be more robust, especially for Nerves users","ref":"changelog.html#v2-4-0-2021-01-09","title":"Changelog - v2.4.0 (2021-01-09)","type":"extras"},{"doc":"Changes using Comeonin v5.3, which changes add_hash so that it does NOT set the password to nil","ref":"changelog.html#v2-3-0-2020-03-01","title":"Changelog - v2.3.0 (2020-03-01)","type":"extras"},{"doc":"Enhancements Updated documentation - in line with updates to Comeonin v5.2","ref":"changelog.html#v2-2-0-2020-01-15","title":"Changelog - v2.2.0 (2020-01-15)","type":"extras"},{"doc":"Enhancements Updated to use the Comeonin and Comeonin.PasswordHash behaviours (Comeonin v5.0) Made Argon2id the default Argon2 type Changed default t_cost, m_cost and parallelism values","ref":"changelog.html#v2-0-0-2019-02-12","title":"Changelog - v2.0.0 (2019-02-12)","type":"extras"},{"doc":"Bug fixes Added :erlang.nif_error for use with NIFs","ref":"changelog.html#v1-3-1-2018-06-28","title":"Changelog - v1.3.1 (2018-06-28)","type":"extras"},{"doc":"Bug fixes Fixed bug that was raising errors when used in releases","ref":"changelog.html#v1-3-2018-05-13","title":"Changelog - v1.3 (2018-05-13)","type":"extras"},{"doc":"Enhancements Improved Windows support by removing VLAs from nif code","ref":"changelog.html#v1-2-4-2018-12-09","title":"Changelog - v1.2.4 (2018-12-09)","type":"extras"},{"doc":"Changes Removed the opts argument to verify_pass - it is now verify_pass/2 Deprecated verify_hash - this will be removed in version 2","ref":"changelog.html#v1-2-0-2017-07-14","title":"Changelog - v1.2.0 (2017-07-14)","type":"extras"},{"doc":"Changes Added a verify_pass function - this is to be more in line with other libraries' verify functions","ref":"changelog.html#v1-1-0-2017-07-12","title":"Changelog - v1.1.0 (2017-07-12)","type":"extras"},{"doc":"Changes Updates to the documentation","ref":"changelog.html#v1-0-0-2017-07-06","title":"Changelog - v1.0.0 (2017-07-06)","type":"extras"},{"doc":"Enhancements Added no_user_verify dummy verify function to help prevent username enumeration","ref":"changelog.html#v0-12-0-2017-01-16","title":"Changelog - v0.12.0 (2017-01-16)","type":"extras"},{"doc":"Enhancements Made t_cost, m_cost and parallelism configurable with the config file This makes it easier to set different values for tests","ref":"changelog.html#v0-11-0-2016-11-09","title":"Changelog - v0.11.0 (2016-11-09)","type":"extras"},{"doc":"Enhancements Added report function This provides an output similar to the reference command line app Changes Changed raw_output and encoded_output options - now there is a single format option","ref":"changelog.html#v0-10-0-2016-11-06","title":"Changelog - v0.10.0 (2016-11-06)","type":"extras"},{"doc":"Bug fixes Fixed hex package","ref":"changelog.html#v0-9-0-2016-10-28","title":"Changelog - v0.9.0 (2016-10-28)","type":"extras"},{"doc":"Apache License Version 2.0 , January 2004 http :// www . apache . org / licenses / TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION Definitions. &quot;License&quot; shall mean the terms and conditions for use, reproduction, and distribution as defined by Sections 1 through 9 of this document. &quot;Licensor&quot; shall mean the copyright owner or entity authorized by the copyright owner that is granting the License. &quot;Legal Entity&quot; shall mean the union of the acting entity and all other entities that control, are controlled by, or are under common control with that entity. For the purposes of this definition, &quot;control&quot; means (i) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (ii) ownership of fifty percent (50%) or more of the outstanding shares, or (iii) beneficial ownership of such entity. &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity exercising permissions granted by this License. &quot;Source&quot; form shall mean the preferred form for making modifications, including but not limited to software source code, documentation source, and configuration files. &quot;Object&quot; form shall mean any form resulting from mechanical transformation or translation of a Source form, including but not limited to compiled object code, generated documentation, and conversions to other media types. &quot;Work&quot; shall mean the work of authorship, whether in Source or Object form, made available under the License, as indicated by a copyright notice that is included in or attached to the work (an example is provided in the Appendix below). &quot;Derivative Works&quot; shall mean any work, whether in Source or Object form, that is based on (or derived from) the Work and for which the editorial revisions, annotations, elaborations, or other modifications represent, as a whole, an original work of authorship. For the purposes of this License, Derivative Works shall not include works that remain separable from, or merely link (or bind by name) to the interfaces of, the Work and Derivative Works thereof. &quot;Contribution&quot; shall mean any work of authorship, including the original version of the Work and any modifications or additions to that Work or Derivative Works thereof, that is intentionally submitted to Licensor for inclusion in the Work by the copyright owner or by an individual or Legal Entity authorized to submit on behalf of the copyright owner. For the purposes of this definition, &quot;submitted&quot; means any form of electronic, verbal, or written communication sent to the Licensor or its representatives, including but not limited to communication on electronic mailing lists, source code control systems, and issue tracking systems that are managed by, or on behalf of, the Licensor for the purpose of discussing and improving the Work, but excluding communication that is conspicuously marked or otherwise designated in writing by the copyright owner as &quot;Not a Contribution.&quot; &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity on behalf of whom a Contribution has been received by Licensor and subsequently incorporated within the Work. Grant of Copyright License. Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright license to reproduce, prepare Derivative Works of, publicly display, publicly perform, sublicense, and distribute the Work and such Derivative Works in Source or Object form. Grant of Patent License. Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable (except as stated in this section) patent license to make, have made, use, offer to sell, sell, import, and otherwise transfer the Work, where such license applies only to those patent claims licensable by such Contributor that are necessarily infringed by their Contribution(s) alone or by combination of their Contribution(s) with the Work to which such Contribution(s) was submitted. If You institute patent litigation against any entity (including a cross-claim or counterclaim in a lawsuit) alleging that the Work or a Contribution incorporated within the Work constitutes direct or contributory patent infringement, then any patent licenses granted to You under this License for that Work shall terminate as of the date such litigation is filed. Redistribution. You may reproduce and distribute copies of the Work or Derivative Works thereof in any medium, with or without modifications, and in Source or Object form, provided that You meet the following conditions: (a) You must give any other recipients of the Work or Derivative Works a copy of this License ; and (b) You must cause any modified files to carry prominent notices stating that You changed the files ; and (c) You must retain, in the Source form of any Derivative Works that You distribute , all copyright , patent , trademark , and attribution notices from the Source form of the Work , excluding those notices that do not pertain to any part of the Derivative Works ; and (d) If the Work includes a &quot;NOTICE&quot; text file as part of its distribution , then any Derivative Works that You distribute must include a readable copy of the attribution notices contained within such NOTICE file , excluding those notices that do not pertain to any part of the Derivative Works , in at least one of the following places : within a NOTICE text file distributed as part of the Derivative Works ; within the Source form or documentation , if provided along with the Derivative Works ; or , within a display generated by the Derivative Works , if and wherever such third - party notices normally appear . The contents of the NOTICE file are for informational purposes only and do not modify the License . You may add Your own attribution notices within Derivative Works that You distribute , alongside or as an addendum to the NOTICE text from the Work , provided that such additional attribution notices cannot be construed as modifying the License . You may add Your own copyright statement to Your modifications and may provide additional or different license terms and conditions for use, reproduction, or distribution of Your modifications, or for any such Derivative Works as a whole, provided Your use, reproduction, and distribution of the Work otherwise complies with the conditions stated in this License. Submission of Contributions. Unless You explicitly state otherwise, any Contribution intentionally submitted for inclusion in the Work by You to the Licensor shall be under the terms and conditions of this License, without any additional terms or conditions. Notwithstanding the above, nothing herein shall supersede or modify the terms of any separate license agreement you may have executed with Licensor regarding such Contributions. Trademarks. This License does not grant permission to use the trade names, trademarks, service marks, or product names of the Licensor, except as required for reasonable and customary use in describing the origin of the Work and reproducing the content of the NOTICE file. Disclaimer of Warranty. Unless required by applicable law or agreed to in writing, Licensor provides the Work (and each Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied, including, without limitation, any warranties or conditions of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are solely responsible for determining the appropriateness of using or redistributing the Work and assume any risks associated with Your exercise of permissions under this License. Limitation of Liability. In no event and under no legal theory, whether in tort (including negligence), contract, or otherwise, unless required by applicable law (such as deliberate and grossly negligent acts) or agreed to in writing, shall any Contributor be liable to You for damages, including any direct, indirect, special, incidental, or consequential damages of any character arising as a result of this License or out of the use or inability to use the Work (including but not limited to damages for loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses), even if such Contributor has been advised of the possibility of such damages. Accepting Warranty or Additional Liability. While redistributing the Work or Derivative Works thereof, You may choose to offer, and charge a fee for, acceptance of support, warranty, indemnity, or other liability obligations and/or rights consistent with this License. However, in accepting such obligations, You may act only on Your own behalf and on Your sole responsibility, not on behalf of any other Contributor, and only if You agree to indemnify, defend, and hold each Contributor harmless for any liability incurred by, or claims asserted against, such Contributor by reason of your accepting any such warranty or additional liability. END OF TERMS AND CONDITIONS","ref":"license.html","title":"License","type":"extras"},{"doc":"Argon2 password hashing library for Elixir. Argon2 is the official winner of the Password Hashing Competition , a several year project to identify a successor to Bcrypt / Pbkdf2 / Scrypt password hashing methods.","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"Add :argon2_elixir to your list of dependencies in mix.exs : def deps do [ { :argon2_elixir , &quot;~&gt; 2.0&quot; } ] end Configure argon2_elixir - see the documentation for Argon2.Stats for more details","ref":"readme.html#installation","title":"Overview - Installation","type":"extras"},{"doc":"See the Comeonin wiki for more information on the following topics: algorithms requirements deployment including information about using Docker references","ref":"readme.html#comeonin-wiki","title":"Overview - Comeonin wiki","type":"extras"},{"doc":"There are many ways you can contribute to the development of this library, including: reporting issues improving documentation sharing your experiences with others Documentation http://hexdocs.pm/argon2_elixir","ref":"readme.html#contributing","title":"Overview - Contributing","type":"extras"},{"doc":"Copyright (c) 2016 David Whitlock Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at https://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"readme.html#copyright-and-license","title":"Overview - Copyright and License","type":"extras"}]